<?php

namespace Drupal\friendlycaptcha\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure Friendly Captcha settings for this site.
 */
class FriendlyCaptchaAdminSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'friendlycaptcha_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['friendlycaptcha.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('friendlycaptcha.settings');

    $form['general'] = [
      '#type' => 'details',
      '#title' => $this->t('General settings'),
      '#open' => TRUE,
    ];

    $form['general']['friendlycaptcha_site_key'] = [
      '#default_value' => $config->get('site_key'),
      '#description' => $this->t('The site key given to you when you <a href=":url">register for Friendly Captcha</a>.', [':url' => 'https://app.friendlycaptcha.com/account']),
      '#maxlength' => 64,
      '#required' => TRUE,
      '#title' => $this->t('Site key'),
      '#type' => 'textfield',
    ];

    $form['general']['friendlycaptcha_api_key'] = [
      '#default_value' => $config->get('api_key'),
      '#description' => $this->t('The API key given to you when you <a href=":url">register for Friendly Captcha</a>.', [':url' => 'https://www.google.com/friendlycaptcha/admin']),
      '#maxlength' => 128,
      '#required' => TRUE,
      '#title' => $this->t('API key'),
      '#type' => 'textfield',
    ];

    $form['general']['friendlycaptcha_api_endpoint'] = [
      '#default_value' => $config->get('api_endpoint'),
      '#options' => [
        'global' => $this->t('Global API-Endpoint'),
        'eu' => $this->t('EU API-Endpoint'),
        'eu_fallback' => $this->t('EU API-Endpoint with fallback to Global APO-Endpoint if not available'),
      ],
      '#description' => $this->t('Select the Friendly Captcha API endpoint for your site. Both, the EU API-Endpoint (and "with fallback to Global API-Endpoint if not available") require a Friendly Captcha Business or Enterprise plan. <a href=":url">See docs for further information.</a>', [':url' => 'https://docs.friendlycaptcha.com/#/eu_endpoint']),
      '#required' => TRUE,
      '#title' => $this->t('API endpoint'),
      '#type' => 'select',
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('friendlycaptcha.settings');
    $config
      ->set('site_key', $form_state->getValue('friendlycaptcha_site_key'))
      ->set('api_key', $form_state->getValue('friendlycaptcha_api_key'))
      ->set('api_endpoint', $form_state->getValue('friendlycaptcha_api_endpoint'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
